import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';

import 'pass_mtx_platform_interface.dart';

/// An implementation of [PassMtxPlatform] that uses method channels.
class MethodChannelPassMtx extends PassMtxPlatform {
  /// The method channel used to interact with the native platform.
  @visibleForTesting
  final methodChannel = const MethodChannel('pass_mtx');

  @override
  Future<String?> getPlatformVersion() async {
    final result =
        await methodChannel.invokeMethod<String>('getPlatformVersion');
    return "$result";
  }

  @override
  Future<String?> getPassPing() async {
    final pingResult = await methodChannel.invokeMethod<String>('getPassPing');
    return "$pingResult";
  }

  @override
  Future<String?> getPassVersion() async {
    final result = await methodChannel.invokeMethod<String>('getPassVersion');
    return "$result";
  }

  @override
  Future<String?> init(String appId, String clientId, String privatePem,
      String publicPem) async {
    final result = await methodChannel.invokeMethod<String>('passInit', {
      "app_id": appId,
      "client_id": clientId,
      "private_pem": privatePem,
      "public_pem": publicPem,
    });
    return "$result";
  }

  @override
  Future<String?> getCard(String userId) async {
    final result = await methodChannel
        .invokeMethod<String>('getCard', {"user_id": userId});
    return "$result";
  }

  @override
  Future<String?> saveCard(String userId, String szPan, String cvv,
      String expDate, String cardHolderName) async {
    final result = await methodChannel.invokeMethod<String>('saveCard', {
      "user_id": userId,
      "card_pan": szPan,
      "cvv": cvv,
      "exp_date": expDate,
      "card_holder_name": cardHolderName
    });
    return "$result";
  }
}
