import 'package:flutter_test/flutter_test.dart';
import 'package:pass_mtx/pass_mtx.dart';
import 'package:pass_mtx/pass_mtx_platform_interface.dart';
import 'package:pass_mtx/pass_mtx_method_channel.dart';
import 'package:plugin_platform_interface/plugin_platform_interface.dart';

class MockPassMtxPlatform
    with MockPlatformInterfaceMixin
    implements PassMtxPlatform {
  @override
  Future<String?> getPlatformVersion() => Future.value('42');

  @override
  Future<String?> getPassPing() => Future.value('Pong');
  @override
  Future<String?> getPassVersion() => Future.value('0.0.1');
  @override
  Future<String?> init(
          String appId, String clientId, String privatePem, String publicPem) =>
      Future.value('ok');
  @override
  Future<String?> getCard(String userId) => Future.value('ok');
  @override
  Future<String?> saveCard(String userId, String szPan, String cvv,
          String expDate, String cardHolderName) =>
      Future.value('ok');
}

void main() {
  final PassMtxPlatform initialPlatform = PassMtxPlatform.instance;

  test('$MethodChannelPassMtx is the default instance', () {
    expect(initialPlatform, isInstanceOf<MethodChannelPassMtx>());
  });

  test('getPlatformVersion', () async {
    PassMtx passMtxPlugin = PassMtx();
    MockPassMtxPlatform fakePlatform = MockPassMtxPlatform();
    PassMtxPlatform.instance = fakePlatform;

    expect(await passMtxPlugin.getPlatformVersion(), '42');
    expect(await passMtxPlugin.getPassPing(), 'pong');
    expect(await passMtxPlugin.getPassVersion(), '0.0.1');
    expect(await passMtxPlugin.init("1", "2", "3", "4"), 'ok');
    expect(await passMtxPlugin.getCard("1"), 'ok');
  });
}
